API Reference
=============

.. module:: wanga


LLM API
-------

.. currentmodule:: wanga.models

Messages
^^^^^^^^

.. automodule:: wanga.models.messages
   :members:

Models
^^^^^^

.. automodule:: wanga.models.model
   :members:


Schema extraction and manipulation
----------------------------------

.. currentmodule:: wanga.schema

Schema Definition
^^^^^^^^^^^^^^^^^

.. automodule:: wanga.schema
   :members:

Schema Extraction
^^^^^^^^^^^^^^^^^

.. automodule:: wanga.schema.extractor
   :members:
